@@ -107,7 +107,9 @@ class SourceStruct:
 				diff_rorp.flaglinked(dest_sig.get_link_flag())
 			elif dest_sig.isreg() and src_rp.isreg():
 				attach_diff(diff_rorp, src_rp, dest_sig)
-			elif src_rp.isreg(): attach_snapshot(diff_rorp, src_rp)
+			elif src_rp.isreg():
+				attach_snapshot(diff_rorp, src_rp)
+				dest_sig.close_if_necessary()
 			else: diff_rorp.set_attached_filetype('snapshot')
 			yield diff_rorp
 
